==> aws-sdk-cpp-1.9.365-2-x86_64.pkg.tar.zst: usr/include/aws/guardduty/model/KubernetesDetails.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/guardduty/GuardDuty_EXPORTS.h>
#include <aws/guardduty/model/KubernetesUserDetails.h>
#include <aws/guardduty/model/KubernetesWorkloadDetails.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace GuardDuty
{
namespace Model
{

  /**
   * <p>Details about Kubernetes resources such as a Kubernetes user or workload
   * resource involved in a Kubernetes finding.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/guardduty-2017-11-28/KubernetesDetails">AWS
   * API Reference</a></p>
   */
  class AWS_GUARDDUTY_API KubernetesDetails
  {
  public:
    KubernetesDetails();
    KubernetesDetails(Aws::Utils::Json::JsonView jsonValue);
    KubernetesDetails& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * <p>Details about the Kubernetes user involved in a Kubernetes finding.</p>
     */
    inline const KubernetesUserDetails& GetKubernetesUserDetails() const{ return m_kubernetesUserDetails; }

    /**
     * <p>Details about the Kubernetes user involved in a Kubernetes finding.</p>
     */
    inline bool KubernetesUserDetailsHasBeenSet() const { return m_kubernetesUserDetailsHasBeenSet; }

    /**
     * <p>Details about the Kubernetes user involved in a Kubernetes finding.</p>
     */
    inline void SetKubernetesUserDetails(const KubernetesUserDetails& value) { m_kubernetesUserDetailsHasBeenSet = true; m_kubernetesUserDetails = value; }

    /**
     * <p>Details about the Kubernetes user involved in a Kubernetes finding.</p>
     */
    inline void SetKubernetesUserDetails(KubernetesUserDetails&& value) { m_kubernetesUserDetailsHasBeenSet = true; m_kubernetesUserDetails = std::move(value); }

    /**
     * <p>Details about the Kubernetes user involved in a Kubernetes finding.</p>
     */
    inline KubernetesDetails& WithKubernetesUserDetails(const KubernetesUserDetails& value) { SetKubernetesUserDetails(value); return *this;}

    /**
     * <p>Details about the Kubernetes user involved in a Kubernetes finding.</p>
     */
    inline KubernetesDetails& WithKubernetesUserDetails(KubernetesUserDetails&& value) { SetKubernetesUserDetails(std::move(value)); return *this;}


    /**
     * <p>Details about the Kubernetes workload involved in a Kubernetes finding.</p>
     */
    inline const KubernetesWorkloadDetails& GetKubernetesWorkloadDetails() const{ return m_kubernetesWorkloadDetails; }

    /**
     * <p>Details about the Kubernetes workload involved in a Kubernetes finding.</p>
     */
    inline bool KubernetesWorkloadDetailsHasBeenSet() const { return m_kubernetesWorkloadDetailsHasBeenSet; }

    /**
     * <p>Details about the Kubernetes workload involved in a Kubernetes finding.</p>
     */
    inline void SetKubernetesWorkloadDetails(const KubernetesWorkloadDetails& value) { m_kubernetesWorkloadDetailsHasBeenSet = true; m_kubernetesWorkloadDetails = value; }

    /**
     * <p>Details about the Kubernetes workload involved in a Kubernetes finding.</p>
     */
    inline void SetKubernetesWorkloadDetails(KubernetesWorkloadDetails&& value) { m_kubernetesWorkloadDetailsHasBeenSet = true; m_kubernetesWorkloadDetails = std::move(value); }

    /**
     * <p>Details about the Kubernetes workload involved in a Kubernetes finding.</p>
     */
    inline KubernetesDetails& WithKubernetesWorkloadDetails(const KubernetesWorkloadDetails& value) { SetKubernetesWorkloadDetails(value); return *this;}

    /**
     * <p>Details about the Kubernetes workload involved in a Kubernetes finding.</p>
     */
    inline KubernetesDetails& WithKubernetesWorkloadDetails(KubernetesWorkloadDetails&& value) { SetKubernetesWorkloadDetails(std::move(value)); return *this;}

  private:

    KubernetesUserDetails m_kubernetesUserDetails;
    bool m_kubernetesUserDetailsHasBeenSet = false;

    KubernetesWorkloadDetails m_kubernetesWorkloadDetails;
    bool m_kubernetesWorkloadDetailsHasBeenSet = false;
  };

} // namespace Model
} // namespace GuardDuty
} // namespace Aws

==> aws-sdk-cpp-1.11.476-1-x86_64.pkg.tar.zst: usr/include/aws/guardduty/model/KubernetesDetails.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/guardduty/GuardDuty_EXPORTS.h>
#include <aws/guardduty/model/KubernetesUserDetails.h>
#include <aws/guardduty/model/KubernetesWorkloadDetails.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace GuardDuty
{
namespace Model
{

  /**
   * <p>Details about Kubernetes resources such as a Kubernetes user or workload
   * resource involved in a Kubernetes finding.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/guardduty-2017-11-28/KubernetesDetails">AWS
   * API Reference</a></p>
   */
  class KubernetesDetails
  {
  public:
    AWS_GUARDDUTY_API KubernetesDetails();
    AWS_GUARDDUTY_API KubernetesDetails(Aws::Utils::Json::JsonView jsonValue);
    AWS_GUARDDUTY_API KubernetesDetails& operator=(Aws::Utils::Json::JsonView jsonValue);
    AWS_GUARDDUTY_API Aws::Utils::Json::JsonValue Jsonize() const;


    ///@{
    /**
     * <p>Details about the Kubernetes user involved in a Kubernetes finding.</p>
     */
    inline const KubernetesUserDetails& GetKubernetesUserDetails() const{ return m_kubernetesUserDetails; }
    inline bool KubernetesUserDetailsHasBeenSet() const { return m_kubernetesUserDetailsHasBeenSet; }
    inline void SetKubernetesUserDetails(const KubernetesUserDetails& value) { m_kubernetesUserDetailsHasBeenSet = true; m_kubernetesUserDetails = value; }
    inline void SetKubernetesUserDetails(KubernetesUserDetails&& value) { m_kubernetesUserDetailsHasBeenSet = true; m_kubernetesUserDetails = std::move(value); }
    inline KubernetesDetails& WithKubernetesUserDetails(const KubernetesUserDetails& value) { SetKubernetesUserDetails(value); return *this;}
    inline KubernetesDetails& WithKubernetesUserDetails(KubernetesUserDetails&& value) { SetKubernetesUserDetails(std::move(value)); return *this;}
    ///@}

    ///@{
    /**
     * <p>Details about the Kubernetes workload involved in a Kubernetes finding.</p>
     */
    inline const KubernetesWorkloadDetails& GetKubernetesWorkloadDetails() const{ return m_kubernetesWorkloadDetails; }
    inline bool KubernetesWorkloadDetailsHasBeenSet() const { return m_kubernetesWorkloadDetailsHasBeenSet; }
    inline void SetKubernetesWorkloadDetails(const KubernetesWorkloadDetails& value) { m_kubernetesWorkloadDetailsHasBeenSet = true; m_kubernetesWorkloadDetails = value; }
    inline void SetKubernetesWorkloadDetails(KubernetesWorkloadDetails&& value) { m_kubernetesWorkloadDetailsHasBeenSet = true; m_kubernetesWorkloadDetails = std::move(value); }
    inline KubernetesDetails& WithKubernetesWorkloadDetails(const KubernetesWorkloadDetails& value) { SetKubernetesWorkloadDetails(value); return *this;}
    inline KubernetesDetails& WithKubernetesWorkloadDetails(KubernetesWorkloadDetails&& value) { SetKubernetesWorkloadDetails(std::move(value)); return *this;}
    ///@}
  private:

    KubernetesUserDetails m_kubernetesUserDetails;
    bool m_kubernetesUserDetailsHasBeenSet = false;

    KubernetesWorkloadDetails m_kubernetesWorkloadDetails;
    bool m_kubernetesWorkloadDetailsHasBeenSet = false;
  };

} // namespace Model
} // namespace GuardDuty
} // namespace Aws
